@@ -4,9 +4,10 @@ use strict;
 use vars qw($VERSION);
 
 use AI::Fuzzy::Set;
+use AI::Fuzzy::Axis;
 use AI::Fuzzy::Label;
 
-$VERSION = '0.02';
+$VERSION = '0.05';
 
 1;
 __END__
@@ -19,10 +20,11 @@ AI::Fuzzy - Perl extension for Fuzzy Logic
 
   use AI::Fuzzy;
 
-  my $f = new AI::Fuzzy::Label;
+  my $f = new AI::Fuzzy::Axis;
+  my $l = new AI::Fuzzy::Label("toddler",      1, 1.5, 3.5);
 
   $f->addlabel("baby",        -1,   1, 2.5);
-  $f->addlabel("toddler",      1, 1.5, 3.5);
+  $f->addlabel($l);
   $f->addlabel("little kid",   2,   7,  12);
   $f->addlabel("kid",          6,  10,  14);
   $f->addlabel("teenager",    12,  16,  20);
@@ -33,7 +35,7 @@ AI::Fuzzy - Perl extension for Fuzzy Logic
 
 
   for (my $x = 0; $x<50; $x+=4) {
-      print "$x years old => " . $f->label($x) . "\n";
+      print "$x years old => " . $f->labelvalue($x) . "\n";
   }
 
   $a = new AI::Fuzzy::Set( x1 => .3, x2 => .5, x3 => .8, x4 => 0, x5 => 1);
@@ -43,7 +45,7 @@ AI::Fuzzy - Perl extension for Fuzzy Logic
   
   print "a is equal to b" if ($a->equal($b));
   
-  $c = $a->complement();
+  my $c = $a->complement();
   print "complement of a is: " . $c->as_string . "\n"; 
   
   $c = $a->union($b);
@@ -56,7 +58,7 @@ __END__
 
 =head1 DESCRIPTION
 
-AI::Fuzzy really consists of two modules - AI::Fuzzy::Label and
+AI::Fuzzy really consists of three modules - AI::Fuzzy::Axis, AI::Fuzzy::Label, and
 AI::Fuzzy::Set.  
 
 A fuzzy set is simply a mathematical set to which members can
@@ -64,12 +66,15 @@ I<partially> belong. For example, a particular shade of gray may
 partially belong to the set of dark colors, whereas black would have
 full membership, and lemon yellow would have almost no membership.
 
-A fuzzy labeler classifies a particular crisp value by examining the
-degree to which it belongs to several sets, and selecting the most
-appropriate. For example, it can decide whether to call water at 60
-degrees Farenheight "cold", "cool", or "warm". A fuzzy label might
-be one of these labels, or a fuzzy set describing to what degree 
-each of the labels describes the particular value in question.
+A fuzzy axis holds fuzzy labels and can be used to classify values
+by examining the degree to which they belong to several labels, and 
+selecting the most appropriate.  For example, it can decide whether 
+to call water at 60 degrees Farenheight "cold", "cool", or "warm". 
+
+A fuzzy label classifies a particular range of the Axis. In the above example 
+the label is one of "cold", "cool", or "warm". A fuzzy label defines how
+much a crisp value belongs to the classifier such as "cold", "warm", or "cool". 
+
 
 
 =head2 Fuzzy Sets
@@ -113,11 +118,11 @@ might look something like this:
 
 
 	
-	  |Y               * (mid, 1)
-	  |               /  \
-	  |             /    \
-	  |           /       \
-	  |         /          \
+	  |Y           * (mid, 1)
+	  |           /  \
+	  |          /     \
+	  |         /       \
+	  |        /          \
 	 -|-------*-------------*------- X
 	           (low,0)      (high,0)
          
@@ -135,18 +140,56 @@ note that labels can overlap, and that the
 mid number isn't always in the exact center, so the slope
 of the two sides may vary...
 
-$fl = new AI::FuzzyLabel;
-
-$fl->addlabel( "hot", 77, 80, 100 );
+$fl = new AI::Fuzzy::Label ( "hot", 77, 80, 100 );
+$fx = new AI::Fuzzy::Label ( "cold", 0, 10, 200 );
     # what I consider hot. :) (in Farenheit, of course!)
 
+if ( $fl->lessthan($fx) ) {
+    print "the laws of nature have changed\n";
+}
+
+# there is a lessthan, greaterthan, lessequal, greaterequal, and between 
+#  that functions as above or using <,>,<=,>=
+
+$a = $fl->applicability($value);
+    # $a is now the degree to which this label applies to $value
+
+=head2 Fuzzy Axis
+
+A Fuzzy::Axis maintains a hash of labels.  Thus you can now look at how
+values apply to the full range of labels.  The graph of an Axis might
+look like this:
+
+
+	
+	  |Y             * (mid, 1)
+	  |           /\/ \      /|
+	  |  /- -\   / /\  \    / |  
+	  | /     \-/ /  \   \ /  |  (some function on some range of x)
+	  | |        /    \   /\  ---*-|
+	 -|---------*-----------*------- X
+	           (low,0)      (high,0)
+         
+
+the Y value is still the applicability of the label for a given X value,
+but there are three labels on this Axis.  A different X value may
+put your value into a new label.
+
+$fl = new AI::Fuzzy::Axis;
+
+$fl->addlabel($label);
+    # add a label created as in AI::Fuzzy::Label docs
+
 $a = $fl->applicability($label, $value);
     # $a is now the degree to which $label applies to $value
 
-$l = $fl->label ($value);
+$l = $fl->label ("labelname");
+    # returns the label object named "labelname"
+
+$l = $fl->labelvalue ($value);
     # applies a label to $value
 
-@l = $fl->label($value);
+@l = $fl->labelvalue($value);
     # returns a list of labels and their applicability values
 
 $s = new AI::Fuzzy::Set( $fl->label($value) );
@@ -155,8 +198,6 @@ $s = new AI::Fuzzy::Set( $fl->label($value) );
 @range = $fl->range();
     # returns a list of labels, sorted by their midpoints
     # eg: ("cold", "cool", "lukewarm", "warm", "hot")
-
-
 =head1 AUTHOR
 
 Tom Scanlan <tscanlan@openreach.com>,
